<?php

/**
 * @file
 * Process payments using Authorize.net. Supports AIM and ARB.
 *
 *
 */


function uc_authnet_cim_bank_update_form($form_state, $rfid) {
  $fee = uc_recurring_fee_user_load($rfid);

  uc_authnet_setup();
  $request = new AuthorizeNetCIM;
  $response = $request->getCustomerPaymentProfile($fee->data['customerProfileId'], $fee->data['customerPaymentProfileId']);
  $order = uc_authnet_cim_xml2order($response->xml);
  $form = uc_order_pane_bill_to('edit-form', $order);
  $form = array_merge($form, uc_authnet_echecknet_payment_form($form_state, $order));

  $form['bill_to']['#collapsed'] = TRUE;

  $form['rfid'] = array(
    '#type' => 'hidden',
    '#value' => $rfid
  );
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Update Account Details'),
    '#suffix' => l(t('Cancel'), uc_referer_uri()),
  );
  return $form;
}

function uc_authnet_cim_bank_update_form_submit($form, &$form_state) {
  global $user;

  uc_authnet_setup();
  $request = new AuthorizeNetCIM;

  $order = new stdClass();
  $order->payment_method = 'echecknet';
  $order->billing_first_name  = $form_state['values']['billing_first_name'];
  $order->billing_last_name   = $form_state['values']['billing_last_name'];
  $order->billing_company     = $form_state['values']['billing_company'];
  $order->billing_street1     = $form_state['values']['billing_street1'];
  $order->billing_city        = $form_state['values']['billing_city'];
  $order->billing_zone        = $form_state['values']['billing_zone'];
  $order->billing_postal_code = $form_state['values']['billing_postal_code'];
  $order->billing_country     = $form_state['values']['billing_country'];

  $order->payment_details['echeck_bank_acct_type'] = $form_state['values']['echeck_bank_acct_type'];
  $order->payment_details['echeck_bank_aba_code'] = $form_state['values']['echeck_bank_aba_code'];
  $order->payment_details['echeck_bank_acct_num'] = $form_state['values']['echeck_bank_acct_num'];
  $order->payment_details['echeck_bank_acct_name'] = $form_state['values']['echeck_bank_acct_name'];
  $order->payment_details['echeck_bank_name'] = $form_state['values']['echeck_bank_name'];

  $fee = uc_recurring_fee_user_load($form_state['values']['rfid']);
  $paymentProfile = uc_authnet_cim_order2xml($order);
  $response = $request->updateCustomerPaymentProfile($fee->data['customerProfileId'], $fee->data['customerPaymentProfileId'], $paymentProfile);
  if ($response->isOk()) {
    drupal_set_message(t('Updated payment details'));
  }
  else {
    drupal_set_message(t('Error [@code] updating payment details, try again, if problem persist please contact the administrator', array('@code' => $response->getMessageCode())), 'error');
    uc_order_comment_save($fee->order_id, $user->uid, _authnet_order_comment($response));
  }
}

/**
 * Form to gather the required fields to process an eCheck payment.
 */
function uc_authnet_echecknet_payment_form($form_state, $order = NULL) {
  $form = array();

  $form['echeck_bank_name'] = array(
    '#type' => 'textfield',
    '#title' => t('Bank name'),
    '#default_value' => (isset($order) ? $order->payment_details['echeck_bank_name'] : ''),
    '#attributes' => array('autocomplete' => 'off'),
    '#required' => TRUE,
    '#maxlength' => 50,
    '#size' => 32,
  );
  $form['echeck_bank_aba_code'] = array(
    '#type' => 'textfield',
    '#title' => t('Bank routing number'),
    '#description' => t('The first 9 digit number along the bottom of your checks.'),
    '#default_value' => (isset($order) ? $order->payment_details['echeck_bank_aba_code'] : ''),
    '#attributes' => array('autocomplete' => 'off'),
    '#required' => TRUE,
    '#maxlength' => 9,
    '#size' => 32,
  );
  $form['echeck_bank_acct_num'] = array(
    '#type' => 'textfield',
    '#title' => t('Bank account number'),
    '#description' => t('Up to a 20 digit number next to the the routing number.'),
    '#default_value' => (isset($order) ? $order->payment_details['echeck_bank_acct_num'] : ''),
    '#attributes' => array('autocomplete' => 'off'),
    '#required' => TRUE,
    '#maxlength' => 20,
    '#size' => 32,
  );
  $form['echeck_bank_acct_name'] = array(
    '#type' => 'textfield',
    '#title' => t('Name on the account'),
    '#default_value' => (isset($order) ? $order->payment_details['echeck_bank_acct_name'] : ''),
    '#attributes' => array('autocomplete' => 'off'),
    '#required' => TRUE,
    '#maxlength' => 50,
    '#size' => 32,
  );
  $form['echeck_bank_acct_type'] = array(
    '#type' => 'select',
    '#title' => t('Bank account type'),
    '#options' => uc_echecknet_acct_type(),
    '#default_value' => !empty($order->payment_details['echeck_bank_acct_type']) ? $order->payment_details['echeck_bank_acct_type'] : 'CHECKING',
    '#required' => TRUE,
  );

  return $form;
}


